==> haskell-cabal-install-parsers-0.6.1.1-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-parsers
version:              0.6.1.1
visibility:           public
id:                   cabal-install-parsers-0.6.1.1-CHSx1FWFK6w5ytZAgcc0rQ
key:                  cabal-install-parsers-0.6.1.1-CHSx1FWFK6w5ytZAgcc0rQ
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  a1344a5a21fa7b2c7fb03131d6bf9a81
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.6.1.1-CHSx1FWFK6w5ytZAgcc0rQ
depends:
    Cabal-syntax-3.10.3.0 aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    base-4.18.2.1 base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    binary-0.8.9.1 binary-instances-1.0.4-LRyqc9c5oY9Dn07NM988NQ
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-GXeKCI4bd7n6SsJ2qNUYhy deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    lukko-0.1.2-GZgz2GUuNGZAAE8i1NHToQ
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-D8lXj4v6hLL5fJ348I6jpg text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-parsers-0.6.1.1-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-parsers
version:              0.6.1.1
visibility:           public
id:                   cabal-install-parsers-0.6.1.1-ClByyKda93s4jY2jxjYsSF
key:                  cabal-install-parsers-0.6.1.1-ClByyKda93s4jY2jxjYsSF
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  f66c69ecac732300502e5b87ac27d04d
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.6.1.1-ClByyKda93s4jY2jxjYsSF
depends:
    Cabal-syntax-3.10.3.0 aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    base-4.18.2.1 base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    binary-0.8.9.1 binary-instances-1.0.4-21lVu4PKcafFMmP9h6qqCY
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-4oSM5otI4Ra8wFWOp2kkt3 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    lukko-0.1.2-E4j9X9UkkjjAmzjgwplom6
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
